scriptname INN_Data hidden

;-------------------------------------------------------------------------------
; Utility functions
;-------------------------------------------------------------------------------

;/------------------------------------------------------------------------------
	Function: GetModName
	Description:
		Used as a prefix to StorageUtil keys to create a namespace for the data
		stored by this mod.  Also, used as the base name of the Papyrus log for
		this mod when running in debug mode.
	Arguments:
		none
	Return Value:
		A unique name for this mod
/;
string function GetModName() global
	return "InnRoomCosts"
endfunction

;/------------------------------------------------------------------------------
	Function: IsDirty
	Description:
		Checks if there are unsaved changes to the data.
	Arguments:
		none
	Return Value:
		true if there are unsaved changes.
/;
bool function IsDirty() global
	return JsonUtil.IsPendingSave(GetModName())
endfunction

;/------------------------------------------------------------------------------
	Function: Save
	Description:
		Saves the data to the JSON file.
	Arguments:
		none
	Return Value:
		none
/;
function Save() global
	JsonUtil.Save(GetModName())
endfunction

;/------------------------------------------------------------------------------
	Function: StringListSort
	Description:
		Sorts the list in ascending order. The list is copied from Json into a
		temporary StorageUtil list because StorageUtil has a list sort API.
		After sorting, the Json list is cleared and then repopulated from the
		now sorted StorageUtil list.
	Arguments:
		asKeyName: The KeyName of the list that is passed to JsonUtil functions
	Return Value:
		none
/;
function StringListSort(string asKeyName) global
	string sValue
	int iCount = JsonUtil.StringListCount(GetModName(), asKeyName)
	int i = 0
	while (i < iCount)
		sValue = JsonUtil.StringListGet(GetModName(), asKeyName, i)
		StorageUtil.StringListAdd(none, "TempList", sValue, true)
		i += 1
	endwhile
	StorageUtil.StringListSort(none, "TempList")
	JsonUtil.StringListClear(GetModName(), asKeyName)
	i = 0
	while (i < iCount)
		sValue = StorageUtil.StringListGet(none, "TempList", i)
		JsonUtil.StringListAdd(GetModName(), asKeyName, sValue, false)
		i += 1
	endwhile
	StorageUtil.StringListClear(none, "TempList")
endfunction

;-------------------------------------------------------------------------------
; Data item wrapper functions
;-------------------------------------------------------------------------------

;/------------------------------------------------------------------------------
	Name: CheckoutTime
	Description:
		The time of day at which the player relinquishes ownership of a bed that
		was rented from an inn.
	Persistence:
		Stored in the json file
	See Also:
		UseCheckoutTime
/;
float function GetCheckoutTime() global
	return JsonUtil.GetFloatValue(GetModName(), "CheckoutTime", GetDefaultCheckoutTime())
endfunction

float function GetDefaultCheckoutTime() global
	return 12.0
endfunction

function SetCheckoutTime(float afValue) global
	JsonUtil.SetFloatValue(GetModName(), "CheckoutTime", afValue)
endfunction

;/------------------------------------------------------------------------------
	Name: DebugMode
	Description:
		A flag used to control whether or not the scripts for this mod write out
		trace information to a log file.
	Persistence:
		Stored in the json file
/;
bool function GetDebugMode() global
	return JsonUtil.GetIntValue(GetModName(), "DebugMode", 0) as bool
endfunction

function SetDebugMode(bool abValue) global
	JsonUtil.SetIntValue(GetModName(), "DebugMode", abValue as int)
endfunction

;/------------------------------------------------------------------------------
	Name: DefaultRoomCost
	Description:
		The default value used for the GlobalVariable RoomCost if the player's
		current location is not recognized as one of the known inn locations.
	Persistence:
		Stored in the json file
/;
int function GetDefaultRoomCost() global
	return JsonUtil.GetIntValue(GetModName(), "DefaultRoomCost", GetDefaultRoomCostDefault())
endfunction

int function GetDefaultRoomCostDefault() global
	return 25
endfunction

function SetDefaultRoomCost(int aiValue) global
	JsonUtil.SetIntValue(GetModName(), "DefaultRoomCost", aiValue)
endfunction

;/------------------------------------------------------------------------------
	Name: InnLocation
	Description:
		A text string that indicates where in Tamriel the inn is located.
	Persistence:
		Stored in the json file
/;
string function GetInnLocation(string asInn) global
	return JsonUtil.GetStringValue(GetModName(), asInn + ".Location", "")
endfunction

function SetInnLocation(string asInn, string asValue) global
	JsonUtil.SetStringValue(GetModName(), asInn + ".Location", asValue)
endfunction

;/------------------------------------------------------------------------------
	Name: InnRoomCost
	Description:
		The room cost for a specified inn.
	Persistence:
		Stored in the json file
/;
int function GetInnRoomCost(string asInn) global
	return JsonUtil.GetIntValue(GetModName(), asInn + ".RoomCost", GetDefaultRoomCost())
endfunction

function SetInnRoomCost(string asInn, int aiValue) global
	JsonUtil.SetIntValue(GetModName(), asInn + ".RoomCost", aiValue)
endfunction

;/------------------------------------------------------------------------------
	Name: ModInns
	Description:
		A list of the names of inns that were added by various mods.  The list
		is auto-sorted as new names are added to maintain the list in
		alphabetical order.
	Persistence:
		Stored in the json file
	See Also:
		VanillaInns
/;
int function ModInnsAdd(string asValue) global
	int iRet = JsonUtil.StringListAdd(GetModName(), "ModInns", asValue, false)
	ModInnsSort()
	return iRet
endfunction

int function ModInnsCount() global
	return JsonUtil.StringListCount(GetModName(), "ModInns")
endfunction

string function ModInnsGet(int aiIndex) global
	return JsonUtil.StringListGet(GetModName(), "ModInns", aiIndex)
endfunction

bool function ModInnsHas(string asValue) global
	return JsonUtil.StringListHas(GetModName(), "ModInns", asValue)
endfunction

function ModInnsSort() global
	StringListSort("ModInns")
endfunction

;/------------------------------------------------------------------------------
	Name: UseColoredLabels
	Description:
		A flag used to control whether or not the MCM displays the names of the
		inns you have visited in color.  To officially visit an inn you need to
		initiate dialog with the innkeeper.  You don't need to actually rent a
		room.
	Persistence:
		Stored in the json file
	See Also:
		CheckoutTime
/;
bool function UseColoredLabels() global
	return JsonUtil.GetIntValue(GetModName(), "UseColoredLabels", 0) as bool
endfunction

function SetUseColoredLabels(bool abValue) global
	JsonUtil.SetIntValue(GetModName(), "UseColoredLabels", abValue as int)
endfunction

;/------------------------------------------------------------------------------
	Name: UseCheckoutTime
	Description:
		A flag used to control whether or not the checkout time is enforced.  If
		the flag is false, then the checkout time is effectively 24 game hours
		from the time the room was rented.  If it is true, then the checkout
		time is specified in the CheckoutTime value.
	Persistence:
		Stored in the json file
	See Also:
		CheckoutTime
/;
bool function UseCheckoutTime() global
	return JsonUtil.GetIntValue(GetModName(), "UseCheckoutTime", 0) as bool
endfunction

function SetUseCheckoutTime(bool abValue) global
	JsonUtil.SetIntValue(GetModName(), "UseCheckoutTime", abValue as int)
endfunction

;/------------------------------------------------------------------------------
	Name: VanillaInns
	Description:
		A list of the names of inns that were present in the base game.
	Persistence:
		Stored in the json file
	See Also:
		ModInns
/;
int function VanillaInnsAdd(string asValue) global
	int iRet = JsonUtil.StringListAdd(GetModName(), "VanillaInns", asValue, false)
	VanillaInnsSort()
	return iRet
endfunction

int function VanillaInnsCount() global
	return JsonUtil.StringListCount(GetModName(), "VanillaInns")
endfunction

string function VanillaInnsGet(int aiIndex) global
	return JsonUtil.StringListGet(GetModName(), "VanillaInns", aiIndex)
endfunction

bool function VanillaInnsHas(string asValue) global
	return JsonUtil.StringListHas(GetModName(), "VanillaInns", asValue)
endfunction

function VanillaInnsSort() global
	StringListSort("VanillaInns")
endfunction

;/------------------------------------------------------------------------------
	Name: Visited
	Description:
		A flag used to track whether or not the player has visited an inn.  The
		player does not have to rent a room to be credited with a visit.  All
		that is needed is to initiate dialog with the inn keeper.
	Persistence:
		Stored game saves
/;
bool function GetVisited(string asInn) global
	string sKey = GetModName() + ".Visited"
	return StorageUtil.StringListHas(none, sKey, asInn)
endfunction

function SetVisited(string asInn, bool abValue) global
	string sKey = GetModName() + ".Visited"
	if (abValue)
		StorageUtil.StringListAdd(none, sKey, asInn, false)
		StorageUtil.StringListSort(none, sKey)
	elseif (StorageUtil.StringListHas(none, sKey, asInn))
		StorageUtil.StringListRemove(none, sKey, asInn)
	endif
endfunction
